Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(64)

Unified Diff: services/ui/ws/server_window.cc

Issue 2833163002: Change ui cursor identifiers to an enum class. (Closed)
Patch Set: OK, it can't be explicit for mac. Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « services/ui/ws/platform_display_default.cc ('k') | services/ui/ws/test_utils.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: services/ui/ws/server_window.cc
diff --git a/services/ui/ws/server_window.cc b/services/ui/ws/server_window.cc
index ca67227dfadaa96f03ba905152fb20b87b1c2bed..2f59aac17171702f6ec3711189f827a13eb55524 100644
--- a/services/ui/ws/server_window.cc
+++ b/services/ui/ws/server_window.cc
@@ -32,10 +32,10 @@ ServerWindow::ServerWindow(ServerWindowDelegate* delegate,
transient_parent_(nullptr),
modal_type_(MODAL_TYPE_NONE),
visible_(false),
// Default to POINTER as CURSOR_NULL doesn't change the cursor, it leaves
// the last non-null cursor.
- cursor_id_(mojom::CursorType::POINTER),
- non_client_cursor_id_(mojom::CursorType::POINTER),
+ cursor_id_(mojom::CursorType::kPointer),
+ non_client_cursor_id_(mojom::CursorType::kPointer),
opacity_(1),
can_focus_(true),
properties_(properties),
@@ -32,10 +32,10 @@ ServerWindow::ServerWindow(ServerWindowDelegate* delegate,
modal_type_(MODAL_TYPE_NONE),
visible_(false),
- // Default to POINTER as CURSOR_NULL doesn't change the cursor, it leaves
+ // Default to kPointer as kNull doesn't change the cursor, it leaves
// the last non-null cursor.
« no previous file with comments | « services/ui/ws/platform_display_default.cc ('k') | services/ui/ws/test_utils.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698